AssetCfa class

Collectible Fungible Asset (CFA) - RGB25.

Constructors

AssetCfa({required String assetId, required String name, String? details, required int precision, required int issuedSupply, required int timestamp, required int addedAt, required Balance balance, Media? media})
Creates an AssetCfa instance.
AssetCfa.fromJson(Map<String, dynamic> json)
Creates an AssetCfa instance from a JSON map.
factory

Properties

addedAt int
Timestamp when added to the wallet.
final
assetId String
The asset ID.
final
balance Balance
Current balance.
final
details String?
Optional details/description.
final
hashCode int
The hash code for this object.
no setterinherited
issuedSupply int
Total issued supply.
final
media Media?
Associated media attachment (optional).
final
name String
The asset name.
final
precision int
Decimal precision.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp int
Creation timestamp.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited