AssetNia class

Non-Inflatable Asset (NIA) - RGB20.

Constructors

AssetNia({required String assetId, required String ticker, required String name, required int precision, int? amounts, required int timestamp, required int addedAt, required Balance balance})
Creates an AssetNia instance.
AssetNia.fromJson(Map<String, dynamic> json)
Creates an AssetNia instance from a JSON map.
factory

Properties

addedAt int
Timestamp when added to the wallet.
final
amounts int?
Total issued amounts (optional).
final
assetId String
The asset ID.
final
balance Balance
Current balance of this asset.
final
hashCode int
The hash code for this object.
no setterinherited
name String
The asset name.
final
precision int
Decimal precision of the asset.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ticker String
The asset ticker symbol.
final
timestamp int
Creation timestamp.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited