AssetSchema enum

Supported RGB asset schemas.

Inheritance
Available extensions

Values

nia → const AssetSchema

Non-Inflatable Asset (NIA) - RGB20.

uda → const AssetSchema

Unique Digital Asset (UDA) - RGB21 (NFT).

cfa → const AssetSchema

Collectible Fungible Asset (CFA) - RGB25.

ifa → const AssetSchema

Inflatable Fungible Asset (IFA).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AssetSchema>
A constant List of the values in this enum, in order of their declaration.