Assignment class

Represents an assignment for a transfer.

Constructors

Assignment({required AssignmentType type, int? amount})
Creates an Assignment instance.

Properties

amount int?
The amount assigned (optional, for fungible assets).
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type AssignmentType
The type of assignment.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the Assignment to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited