Balance class

Represents the balance of an asset or Bitcoin.

Constructors

Balance({required int settled, required int future, required int spendable})
Creates a Balance instance.
Balance.fromJson(Map<String, dynamic> json)
Creates a Balance instance from a JSON map.
factory

Properties

future int
The future balance (settled + pending).
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settled int
The settled balance.
final
spendable int
The spendable balance.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited