BtcBalance class

Represents the Bitcoin balance, separated by vanilla and colored (RGB) funds.

Constructors

BtcBalance({required Balance vanilla, required Balance colored})
Creates a BtcBalance instance.
BtcBalance.fromJson(Map<String, dynamic> json)
Creates a BtcBalance instance from a JSON map.
factory

Properties

colored Balance
Balance of colored (RGB-carrying) funds.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vanilla Balance
Balance of vanadium (native Bitcoin) funds.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited