Keys class

Keys associated with the wallet.

Constructors

Keys({required String mnemonic, required String xpub, required String accountXpubVanilla, required String accountXpubColored, required String masterFingerprint})
Creates a Keys instance.
Keys.fromJson(Map<String, dynamic> json)
Creates a Keys instance from a JSON map.
factory

Properties

accountXpubColored String
Extended public key for the colored keychain.
final
accountXpubVanilla String
Extended public key for the vanilla keychain.
final
hashCode int
The hash code for this object.
no setterinherited
masterFingerprint String
The master fingerprint.
final
mnemonic String
The mnemonic phrase.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
xpub String
The extended public key (xpub).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited