Media class

Media attachment.

Constructors

Media({required String filePath, required String mime})
Creates a Media instance.
Media.fromJson(Map<String, dynamic> json)
Creates a Media instance from a JSON map.
factory

Properties

filePath String
Path to the media file.
final
hashCode int
The hash code for this object.
no setterinherited
mime String
MIME type of the media.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the Media to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited