RefreshTransferStatusUpdate class
Update on the status of a transfer.
Constructors
- RefreshTransferStatusUpdate({RefreshTransferStatus? updatedStatus, String? failure})
- Creates a RefreshTransferStatusUpdate instance.
-
RefreshTransferStatusUpdate.fromJson(Map<
String, dynamic> json) -
Creates a RefreshTransferStatusUpdate instance from a JSON map.
factory
Properties
- failure → String?
-
Failure reason (if any).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatedStatus → RefreshTransferStatus?
-
The updated status.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited