Transaction class

Represents a transaction.

Constructors

Transaction({required TransactionType transactionType, required String txid, required int received, required int sent, required int fee, int? confirmationTime})
Creates a Transaction instance.
Transaction.fromJson(Map<String, dynamic> json)
Creates a Transaction instance from a JSON map.
factory

Properties

confirmationTime int?
Confirmation time (timestamp).
final
fee int
Transaction fee (in satoshis).
final
hashCode int
The hash code for this object.
no setterinherited
received int
Amount received (in satoshis).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sent int
Amount sent (in satoshis).
final
transactionType TransactionType
The type of transaction.
final
txid String
The transaction ID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited