Unspent class

Represents an unspent transaction output (UTXO).

Constructors

Unspent({required String utxo, required int vout, required int amount, required String colorable, required int rgbAllocations})
Creates an Unspent instance.
Unspent.fromJson(Map<String, dynamic> json)
Creates an Unspent instance from a JSON map.
factory

Properties

amount int
The amount in satoshis.
final
colorable String
Whether the UTXO is colorable (can hold RGB assets).
final
hashCode int
The hash code for this object.
no setterinherited
rgbAllocations int
Number of RGB allocations on this UTXO.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
utxo String
The specific UTXO identifier (txid:vout).
final
vout int
The output index (vout).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited