WalletData class
Data associated with an RGB wallet.
Constructors
-
WalletData({required String dataDir, required String bitcoinNetwork, required String databaseType, required int maxAllocationsPerUtxo, required String accountXpubVanilla, required String accountXpubColored, String? mnemonic, required String masterFingerprint, int? vanillaKeychain, required List<
String> supportedSchemas}) - Creates a WalletData instance.
-
WalletData.fromJson(Map<
String, dynamic> json) -
Creates a WalletData instance from a JSON map.
factory
Properties
- accountXpubColored → String
-
Extended public key for the colored (RGB) keychain.
final
- accountXpubVanilla → String
-
Extended public key for the vanilla (Bitcon-only) keychain.
final
- bitcoinNetwork → String
-
The Bitcoin network this wallet is on.
final
- databaseType → String
-
The database type used.
final
- dataDir → String
-
Directory where wallet data is stored.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- masterFingerprint → String
-
Master fingerprint of the wallet's key.
final
- maxAllocationsPerUtxo → int
-
Maximum allocations allowed per UTXO.
final
- mnemonic → String?
-
Mnemonic phrase (optional).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
supportedSchemas
→ List<
String> -
List of supported asset schemas.
final
- vanillaKeychain → int?
-
Number of the vanilla keychain.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited