WitnessData class

Data for witness transactions.

Constructors

WitnessData({required int amountSat, int? blinding})
Creates a WitnessData instance.

Properties

amountSat int
Amount in satoshis.
final
blinding int?
Blinding factor (optional).
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the WitnessData to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited