AssetIfa class
Inflatable Fungible Asset (IFA).
Constructors
- AssetIfa({required String assetId, required String ticker, required String name, String? details, required int precision, required int initialSupply, required int maxSupply, required int knownCirculatingSupply, required int timestamp, required int addedAt, required Balance balance, Media? media, String? rejectListUrl})
- Creates an AssetIfa instance.
-
AssetIfa.fromJson(Map<
String, dynamic> json) -
Creates an AssetIfa instance from a JSON map.
factory
Properties
- addedAt → int
-
Timestamp when added to the wallet.
final
- assetId → String
-
The asset ID.
final
- balance → Balance
-
Current balance.
final
- details → String?
-
Optional details/description.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialSupply → int
-
Initial supply issued.
final
- knownCirculatingSupply → int
-
Known circulating supply.
final
- maxSupply → int
-
Maximum supply possible.
final
- media → Media?
-
Associated media attachment (optional).
final
- name → String
-
The asset name.
final
- precision → int
-
Decimal precision.
final
- rejectListUrl → String?
-
URL for the reject list (if applicable).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ticker → String
-
The asset ticker symbol.
final
- timestamp → int
-
Creation timestamp.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited