AssetUda class
Unique Digital Asset (UDA) - RGB21 (NFT).
Constructors
-
AssetUda({required String assetId, required String ticker, required String name, String? details, required int precision, required int timestamp, required int addedAt, required Balance balance, Media? media, List<
Media> ? attachments}) - Creates an AssetUda instance.
-
AssetUda.fromJson(Map<
String, dynamic> json) -
Creates an AssetUda instance from a JSON map.
factory
Properties
- addedAt → int
-
Timestamp when added to the wallet.
final
- assetId → String
-
The asset ID.
final
-
attachments
→ List<
Media> ? -
List of additional attachments (optional).
final
- balance → Balance
-
Current balance.
final
- details → String?
-
Optional details/description.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- media → Media?
-
Associated media attachment (optional).
final
- name → String
-
The asset name.
final
- precision → int
-
Decimal precision.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ticker → String
-
The asset ticker symbol.
final
- timestamp → int
-
Creation timestamp.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited