Assets class
Collection of assets held by the wallet.
Constructors
Properties
-
cfa
→ List<
AssetCfa> -
List of collectible fungible assets (CFA).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ifa
→ List<
AssetIfa> -
List of inflatable fungible assets (IFA).
final
-
nia
→ List<
AssetNia> -
List of non-inflatable assets (NIA).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
uda
→ List<
AssetUda> -
List of unique digital assets (UDA).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited