ReceiveData class
Data for receiving an RGB transfer.
Constructors
- ReceiveData({required String invoice, required String recipientId, int? expirationTimestamp, required int batchTransferIdx})
- Creates a ReceiveData instance.
-
ReceiveData.fromJson(Map<
String, dynamic> json) -
Creates a ReceiveData instance from a JSON map.
factory
Properties
- batchTransferIdx → int
-
The batch transfer index.
final
- expirationTimestamp → int?
-
Expiration timestamp of the invoice/data.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- invoice → String
-
The invoice string (e.g., Lightning invoice).
final
- recipientId → String
-
The recipient ID (e.g., blinded UTXO).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited