Recipient class
Represents a recipient of a transfer.
Constructors
-
Recipient({required String recipientId, WitnessData? witnessData, required Assignment assignment, required List<
String> transportEndpoints}) - Creates a Recipient instance.
Properties
- assignment → Assignment
-
The assignment for this recipient.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- recipientId → String
-
The recipient ID (e.g., blinded UTXO).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
transportEndpoints
→ List<
String> -
Transport endpoints for the transfer.
final
- witnessData → WitnessData?
-
Witness data (for witness transfers).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts the Recipient to a JSON map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited