RgbLibErrors class abstract
Error codes returned by the RGB library.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- allocationsAlreadyAvailable → const String
- Allocations are already available on the UTXO.
- assetNotFound → const String
- Asset not found.
- batchTransferNotFound → const String
- Batch transfer not found.
- bitcoinNetworkMismatch → const String
- Bitcoin network mismatch.
- cannotChangeOnline → const String
- Cannot perform operation while online.
- cannotDeleteBatchTransfer → const String
- Cannot delete batch transfer.
- cannotEstimateFees → const String
- cannotFailBatchTransfer → const String
- cannotFinalizePsbt → const String
- cannotUseIfaOnMainnet → const String
- emptyFile → const String
- failedBdkSync → const String
- failedBroadcast → const String
- failedIssuance → const String
- fileAlreadyExists → const String
- fingerprintMismatch → const String
- Fingerprint mismatch.
- inconsistency → const String
- Inconsistency error.
- indexer → const String
- Indexer error.
- inexistentDataDir → const String
- Data directory does not exist.
- insufficientAllocationSlots → const String
- Insufficient allocation slots.
- insufficientAssignments → const String
- Insufficient assignments.
- insufficientBitcoins → const String
- Insufficient bitcoins.
- internal → const String
- Internal error.
- invalidAddress → const String
- Invalid address.
- invalidAmountZero → const String
- Invalid amount (zero).
- invalidAssetId → const String
- Invalid asset ID.
- invalidAssignment → const String
- Invalid assignment.
- invalidAttachments → const String
- Invalid attachments.
- invalidBitcoinKeys → const String
- Invalid Bitcoin keys.
- invalidBitcoinNetwork → const String
- Invalid Bitcoin network.
- invalidColoringInfo → const String
- Invalid coloring info.
- invalidConsignment → const String
- Invalid consignment.
- invalidDetails → const String
- Invalid details.
- invalidElectrum → const String
- Invalid Electrum URL.
- invalidEstimationBlocks → const String
- Invalid estimation blocks.
- invalidFeeRate → const String
- Invalid fee rate.
- invalidFilePath → const String
- Invalid file path.
- invalidFingerprint → const String
- Invalid fingerprint.
- invalidIndexer → const String
- Invalid indexer.
- invalidInvoice → const String
- Invalid invoice.
- invalidMnemonic → const String
- Invalid mnemonic.
- invalidName → const String
- Invalid name.
- invalidPrecision → const String
- Invalid precision.
- invalidProxyProtocol → const String
- Invalid proxy protocol.
- invalidPsbt → const String
- Invalid PSBT.
- invalidPubkey → const String
- Invalid public key.
- invalidRecipientData → const String
- Invalid recipient data.
- invalidRecipientId → const String
- Invalid recipient ID.
- invalidRecipientNetwork → const String
- Invalid recipient network.
- invalidRejectListUrl → const String
- Invalid reject list URL.
- invalidTicker → const String
- Invalid ticker.
- invalidTransportEndpoint → const String
- Invalid transport endpoint.
- invalidTransportEndpoints → const String
- Invalid transport endpoints.
- invalidTxid → const String
- Invalid transaction ID.
- invalidVanillaKeychain → const String
- Invalid vanilla keychain.
- io → const String
- I/O error.
- maxFeeExceeded → const String
- Max fee exceeded.
- minFeeNotMet → const String
- Min fee not met.
- network → const String
- Network error.
- noConsignment → const String
- No consignment found.
- noInflationAmounts → const String
- No inflation amounts provided.
- noIssuanceAmounts → const String
- No issuance amounts provided.
- noSupportedSchemas → const String
- No supported schemas.
- noValidTransportEndpoint → const String
- No valid transport endpoint found.
- offline → const String
- Wallet is offline.
- onlineNeeded → const String
- Wallet must be online.
- outputBelowDustLimit → const String
- Output is below dust limit.
- proxy → const String
- Proxy error.
- recipientIdAlreadyUsed → const String
- Recipient ID already used.
- recipientIdDuplicated → const String
- Recipient ID duplicated.
- rejectListService → const String
- Reject list service error.
- restClientBuild → const String
- REST client build error.
- tooHighInflationAmounts → const String
- Inflation amounts too high.
- tooHighIssuanceAmounts → const String
- Issuance amounts too high.
- unknownRgbSchema → const String
- Unknown RGB schema.
- unknownTransfer → const String
- Unknown transfer.
- unsupportedBackupVersion → const String
- Unsupported backup version.
- unsupportedInflation → const String
- Unsupported inflation.
- unsupportedLayer1 → const String
- Unsupported Layer 1.
- unsupportedSchema → const String
- Unsupported schema.
- unsupportedTransportType → const String
- Unsupported transport type.
- walletDirAlreadyExists → const String
- Wallet directory already exists.
- watchOnly → const String
- Wallet is watch-only.
- wrongPassword → const String
- Wrong password.