Transfer class
Represents an RGB transfer.
Constructors
- Transfer({required int transferIdx, required int batchTransferIdx, required int createdAt, required int updatedAt, required TransferKind kind, required TransferStatus status, String? txid, String? recipientId, int? receiveUtxo, int? changeUtxo, int? expiration, required String transportEndpoints, String? invoiceString, String? consignmentPath, required int assignments})
- Creates a Transfer instance.
-
Transfer.fromJson(Map<
String, dynamic> json) -
Creates a Transfer instance from a JSON map.
factory
Properties
- assignments → int
-
Total assigned amount.
final
- batchTransferIdx → int
-
The batch transfer index.
final
- changeUtxo → int?
-
The change UTXO (optional).
final
- consignmentPath → String?
-
Path to the consignment file (optional).
final
- createdAt → int
-
Creation timestamp.
final
- expiration → int?
-
Expiration timestamp (optional).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- invoiceString → String?
-
The invoice string (optional).
final
- kind → TransferKind
-
The kind of transfer.
final
- receiveUtxo → int?
-
The receive UTXO (optional).
final
- recipientId → String?
-
The recipient ID (optional).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → TransferStatus
-
The status of the transfer.
final
- transferIdx → int
-
The transfer index.
final
- transportEndpoints → String
-
Transport endpoints.
final
- txid → String?
-
The transaction ID (optional).
final
- updatedAt → int
-
Last update timestamp.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited